<?php

namespace Drupal\personal_digest;

use Drupal\Core\Link;
use Drupal\views\Views;
use Drupal\user\Entity\User;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a user password reset form.
 */
class SiteSettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'personal_digest_site_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $checkboxes = $options = [];
    foreach (Views::getViewsAsOptions(FALSE, 'enabled') as $key => &$view_display) {
      list($view_id, $display_id) = explode(':', $key);
      $view = \Drupal\views\Entity\View::load($view_id)->getExecutable();
      $view->setDisplay($display_id);
      if (digestible($view)) {
        $options[$key] = $view_display;
      }
    }
    if (\Drupal::moduleHandler()->moduleExists('views_ui')) {
      foreach ($options as $key => $view_display) {
        list($view_id, $display_id) = explode(':', $key);
        $options[$key] = Link::createFromRoute(
          $view_display,
          'entity.view.edit_display_form',
          ['view' => $view_id, 'display_id' => $display_id],
          // Todo open in a new window.
          $options
        )->toString();
      }
    }
    if ($options) {
      $form['views'] = [
        '#title' => $this->t('Available views displays.'),
        '#description' => $this->t("Views displays with a first contextual filter '@arg'.", ['@arg' => 'date_fulldate_since']),
        '#type' => 'checkboxes',
        '#options' => $options,
        '#default_value' => $this->config('personal_digest.settings')->get('views'),
      ] + $checkboxes;

      $form['actions'] = [
        '#type' => 'actions',
        'submit' => [
          '#type' => 'submit',
          '#value' => $this->t('Submit'),
        ],
        'test' => [
          '#type' => 'submit',
          '#value' => $this->t('Submit & test'),
          '#submit' => [[$this, 'test']]
        ],
      ];
    }
    else {
      drupal_set_message(t("There are no views yet with with a '@name' argument", ['@name' => 'date_fulldate_since']));
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->config('personal_digest.settings')
        ->set('views', array_values(array_filter($values['views'])))
        ->save();
    parent::submitForm($form, $form_state);
  }

  /**
   * Submit callback
   */
  public function test(array &$form, FormStateInterface $form_state) {
    $this->submitForm($form, $form_state);
    $recipient = User::load(\Drupal::currentUser()->id());
    \Drupal::service('plugin.manager.mail')
      ->mail('personal_digest',
        'digest',
        $recipient->getEmail(),
        $recipient->getPreferredLangcode(),
        [
          'user' => $recipient,
          'displays' => array_filter($form_state->getValue('views')),
          'weeks_interval' => 4,
          'last' => strtotime('-1 month'),
        ]
      );
    drupal_set_message('Check your mail');
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['personal_digest.settings'];
  }


}
