<?php

namespace Drupal\smallads\Plugin\QueueWorker;

use Drupal\Core\Queue\QueueWorkerBase;

/**
 * Updates a feed's items.
 *
 * @QueueWorker(
 *   id = "smallads_expired_mail",
 *   title = @Translation("Smallad expiry notification"),
 *   cron = {"time" = 60}
 * )
 */
class ExpiredMail extends QueueWorkerBase {

  /**
   * {@inheritdoc}
   *
   * @todo make a settings form and variables for the text of the notifcation mail.
   */
  public function processItem($ad_id) {
    $ad = SmallAd::load($ad_id)->expire()->save();
    $owner = $ad->getowner();
    $langcode = $owner->getPreferredLangcode();

    $subject = t(
      'Your @type has expired',
      ['@type' => strtolower($ad->type->entity->label())],
      ['langcode' => $langcode]
    );
    $body[] = $ad->getOwner()->label() . ',';
    $body[] = t(
      "Your post to @sitename,\n\n'@title'\n\n has been unpublished.",
      [
        '@sitename' => \Drupal::config('system.site')->get('name'),
        '@title' => $ad->getLabel(),
      ],
      ['langcode' => $langcode]
    );


    \Drupal::service('plugin.manager.mail')
      ->mail('smallads',
        'expired',
        $owner->getEmail(),
        $langcode,
        [
          'subject' => $subject,
          'body' => $body,
          'ad' => $ad
        ]
      );

    \Drupal::logger('smallads')->info(
      'cron expired ad @id and notified !user (@uid) at @mail',
      [
        '@id' => l($ad->id(), Url::fromRoute('entity.smallad.canonical', ['smallad' => $ad->id()])),
        '%user' => $ad->getOwner()->getDisplayName(),
        '@uid' => $ad->getOwner()->id(),
        '@mail' => $ad->getowner()->getEmail(),
      ]
    );
  }

}
