<?php

namespace Drupal\smallads\Plugin\migrate\source\d7;

use Drupal\migrate\Row;
use Drupal\migrate_drupal\Plugin\migrate\source\d7\FieldableEntity;

/**
 * Drupal 7 proposition nodes in source db.
 *
 * @MigrateSource(
 *   id = "d7_smallad",
 *   source_provider = "offers_wants"
 * )
 */
class Smallad extends FieldableEntity {

  /**
   * {@inheritdoc}
   */
  public function query() {
    $query = $this->select('node', 'n');
    $query->innerJoin('offers_wants', 'ow', 'ow.nid = n.nid');
    $query->fields('n', ['nid', 'title', 'uid', 'created', 'changed', 'status', 'language'])
      ->condition('type', 'proposition');
    $query->addField('ow', 'end', 'end');
    $query->addField('ow', 'want', 'want');
    return $query;
  }

  /**
   * {@inheritdoc}
   */
  public function prepareRow(Row $row) {
    parent::prepareRow($row);
    $row->setSourceProperty('type', $row->getSourceProperty('want') ? 'want' : 'offer');
    //$row->setSourceProperty('date', $row->getSourceProperty('end'));
  }

  /**
   * {@inheritdoc}
   */
  public function fields() {
    $fields = [
      'nid' => $this->t('Node ID'),
      'title' => $this->t('Title'),
      'uid' => $this->t('Node authored by (uid)'),
      'created' => $this->t('Created timestamp'),
      'changed' => $this->t('Modified timestamp'),
      'status' => $this->t('Published'),
      'language' => $this->t('Language (fr, en, ...)'),
      'end' => $this->t('Expiry date'),
      'want' => $this->t('Smallad_type')
    ];
    return $fields;
  }

  /**
   * {@inheritdoc}
   */
  public function getIds() {
    return [
      'nid' => [
        'type' => 'integer',
        'alias' => 'n'
      ]
    ];
  }

}
